# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.convert_scc_position_mode import ConvertSccPositionMode
import pprint
import six


class ConvertSccCaptionWebVttSettings(object):
    @poscheck_model
    def __init__(self,
                 position_mode=None,
                 remove_flash=None,
                 remove_color=None):
        # type: (ConvertSccPositionMode, bool, bool) -> None

        self._position_mode = None
        self._remove_flash = None
        self._remove_color = None
        self.discriminator = None

        if position_mode is not None:
            self.position_mode = position_mode
        if remove_flash is not None:
            self.remove_flash = remove_flash
        if remove_color is not None:
            self.remove_color = remove_color

    @property
    def openapi_types(self):
        types = {
            'position_mode': 'ConvertSccPositionMode',
            'remove_flash': 'bool',
            'remove_color': 'bool'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'position_mode': 'positionMode',
            'remove_flash': 'removeFlash',
            'remove_color': 'removeColor'
        }
        return attributes

    @property
    def position_mode(self):
        # type: () -> ConvertSccPositionMode
        """Gets the position_mode of this ConvertSccCaptionWebVttSettings.


        :return: The position_mode of this ConvertSccCaptionWebVttSettings.
        :rtype: ConvertSccPositionMode
        """
        return self._position_mode

    @position_mode.setter
    def position_mode(self, position_mode):
        # type: (ConvertSccPositionMode) -> None
        """Sets the position_mode of this ConvertSccCaptionWebVttSettings.


        :param position_mode: The position_mode of this ConvertSccCaptionWebVttSettings.
        :type: ConvertSccPositionMode
        """

        if position_mode is not None:
            if not isinstance(position_mode, ConvertSccPositionMode):
                raise TypeError("Invalid type for `position_mode`, type has to be `ConvertSccPositionMode`")

        self._position_mode = position_mode

    @property
    def remove_flash(self):
        # type: () -> bool
        """Gets the remove_flash of this ConvertSccCaptionWebVttSettings.

        Remove flash (blinking) information when converting SCC to WebVTT

        :return: The remove_flash of this ConvertSccCaptionWebVttSettings.
        :rtype: bool
        """
        return self._remove_flash

    @remove_flash.setter
    def remove_flash(self, remove_flash):
        # type: (bool) -> None
        """Sets the remove_flash of this ConvertSccCaptionWebVttSettings.

        Remove flash (blinking) information when converting SCC to WebVTT

        :param remove_flash: The remove_flash of this ConvertSccCaptionWebVttSettings.
        :type: bool
        """

        if remove_flash is not None:
            if not isinstance(remove_flash, bool):
                raise TypeError("Invalid type for `remove_flash`, type has to be `bool`")

        self._remove_flash = remove_flash

    @property
    def remove_color(self):
        # type: () -> bool
        """Gets the remove_color of this ConvertSccCaptionWebVttSettings.

        Remove color information when converting SCC to WebVTT

        :return: The remove_color of this ConvertSccCaptionWebVttSettings.
        :rtype: bool
        """
        return self._remove_color

    @remove_color.setter
    def remove_color(self, remove_color):
        # type: (bool) -> None
        """Sets the remove_color of this ConvertSccCaptionWebVttSettings.

        Remove color information when converting SCC to WebVTT

        :param remove_color: The remove_color of this ConvertSccCaptionWebVttSettings.
        :type: bool
        """

        if remove_color is not None:
            if not isinstance(remove_color, bool):
                raise TypeError("Invalid type for `remove_color`, type has to be `bool`")

        self._remove_color = remove_color

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConvertSccCaptionWebVttSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.encodings.sidecars.webvtt.webvtt_api import WebvttApi
from bitmovin_api_sdk.encoding.encodings.sidecars.webvtt.web_vtt_sidecar_file_list_query_params import WebVttSidecarFileListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.output import Output
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.outputs.type.type_api import TypeApi
from bitmovin_api_sdk.encoding.outputs.s3.s3_api import S3Api
from bitmovin_api_sdk.encoding.outputs.s3_role_based.s3_role_based_api import S3RoleBasedApi
from bitmovin_api_sdk.encoding.outputs.generic_s3.generic_s3_api import GenericS3Api
from bitmovin_api_sdk.encoding.outputs.local.local_api import LocalApi
from bitmovin_api_sdk.encoding.outputs.gcs.gcs_api import GcsApi
from bitmovin_api_sdk.encoding.outputs.gcs_service_account.gcs_service_account_api import GcsServiceAccountApi
from bitmovin_api_sdk.encoding.outputs.azure.azure_api import AzureApi
from bitmovin_api_sdk.encoding.outputs.ftp.ftp_api import FtpApi
from bitmovin_api_sdk.encoding.outputs.sftp.sftp_api import SftpApi
from bitmovin_api_sdk.encoding.outputs.akamai_msl.akamai_msl_api import AkamaiMslApi
from bitmovin_api_sdk.encoding.outputs.akamai_netstorage.akamai_netstorage_api import AkamaiNetstorageApi
from bitmovin_api_sdk.encoding.outputs.live_media_ingest.live_media_ingest_api import LiveMediaIngestApi
from bitmovin_api_sdk.encoding.outputs.cdn.cdn_api import CdnApi
from bitmovin_api_sdk.encoding.outputs.output_list_query_params import OutputListQueryParams


class OutputsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(OutputsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.type = TypeApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.s3 = S3Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.s3_role_based = S3RoleBasedApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.generic_s3 = GenericS3Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.local = LocalApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.gcs = GcsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.gcs_service_account = GcsServiceAccountApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.azure = AzureApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.ftp = FtpApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.sftp = SftpApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.akamai_msl = AkamaiMslApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.akamai_netstorage = AkamaiNetstorageApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.live_media_ingest = LiveMediaIngestApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.cdn = CdnApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def get(self, output_id, **kwargs):
        # type: (string_types, dict) -> Output
        """Get Output Details

        :param output_id: Id of the wanted output
        :type output_id: string_types, required
        :return: Output details
        :rtype: Output
        """

        return self.api_client.get(
            '/encoding/outputs/{output_id}',
            path_params={'output_id': output_id},
            type=Output,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (OutputListQueryParams, dict) -> Output
        """List all Outputs

        :param query_params: Query parameters
        :type query_params: OutputListQueryParams
        :return: All outputs with type information. The specific properties for each type are also included. These are the same as in the list call for a specific type.
        :rtype: Output
        """

        return self.api_client.get(
            '/encoding/outputs',
            query_params=query_params,
            pagination_response=True,
            type=Output,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class WebhookHttpMethod(Enum):
    POST = "POST"
    PUT = "PUT"



from bitmovin_api_sdk.encoding.encodings.streams.watermarking.nexguard_file_marker.nexguard_file_marker_api import NexguardFileMarkerApi
from bitmovin_api_sdk.encoding.encodings.streams.watermarking.nexguard_file_marker.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.streams.watermarking.nexguard_file_marker.nex_guard_file_marker_list_query_params import NexGuardFileMarkerListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.notification import Notification
from bitmovin_api_sdk.models.notification_state_entry import NotificationStateEntry
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.notifications.webhooks.webhooks_api import WebhooksApi
from bitmovin_api_sdk.notifications.states.states_api import StatesApi
from bitmovin_api_sdk.notifications.emails.emails_api import EmailsApi
from bitmovin_api_sdk.notifications.notification_list_query_params import NotificationListQueryParams
from bitmovin_api_sdk.notifications.notification_state_entry_list_by_notification_id_query_params import NotificationStateEntryListByNotificationIdQueryParams


class NotificationsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(NotificationsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.webhooks = WebhooksApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.states = StatesApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.emails = EmailsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def delete(self, notification_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete Notification

        :param notification_id: Id of the notification
        :type notification_id: string_types, required
        :return: Id of the notification
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/notifications/{notification_id}',
            path_params={'notification_id': notification_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, notification_id, **kwargs):
        # type: (string_types, dict) -> Notification
        """Get Notification

        :param notification_id: Id of the notification
        :type notification_id: string_types, required
        :return: Webhook Details
        :rtype: Notification
        """

        return self.api_client.get(
            '/notifications/{notification_id}',
            path_params={'notification_id': notification_id},
            type=Notification,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (NotificationListQueryParams, dict) -> Notification
        """List Notifications

        :param query_params: Query parameters
        :type query_params: NotificationListQueryParams
        :return: List of Notifications
        :rtype: Notification
        """

        return self.api_client.get(
            '/notifications',
            query_params=query_params,
            pagination_response=True,
            type=Notification,
            **kwargs
        )

    def list_by_notification_id(self, notification_id, query_params=None, **kwargs):
        # type: (string_types, NotificationStateEntryListByNotificationIdQueryParams, dict) -> NotificationStateEntry
        """List Notification State History (All Resources)

        :param notification_id: Id of the notification
        :type notification_id: string_types, required
        :param query_params: Query parameters
        :type query_params: NotificationStateEntryListByNotificationIdQueryParams
        :return: List of state entries
        :rtype: NotificationStateEntry
        """

        return self.api_client.get(
            '/notifications/{notification_id}/states',
            path_params={'notification_id': notification_id},
            query_params=query_params,
            pagination_response=True,
            type=NotificationStateEntry,
            **kwargs
        )

    def mute(self, notification_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Mute Notification

        :param notification_id: Id of the notification
        :type notification_id: string_types, required
        :return: Id of the notification
        :rtype: BitmovinResponse
        """

        return self.api_client.post(
            '/notifications/{notification_id}/mute',
            path_params={'notification_id': notification_id},
            type=BitmovinResponse,
            **kwargs
        )

    def unmute(self, notification_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Unmute Notification

        :param notification_id: Id of the notification
        :type notification_id: string_types, required
        :return: Id of the notification
        :rtype: BitmovinResponse
        """

        return self.api_client.post(
            '/notifications/{notification_id}/unmute',
            path_params={'notification_id': notification_id},
            type=BitmovinResponse,
            **kwargs
        )



from bitmovin_api_sdk.player.custom_builds.web.web_api import WebApi
from bitmovin_api_sdk.player.custom_builds.web.domains.domains_api import DomainsApi
from bitmovin_api_sdk.player.custom_builds.web.status.status_api import StatusApi
from bitmovin_api_sdk.player.custom_builds.web.download.download_api import DownloadApi



from bitmovin_api_sdk.encoding.filters.enhanced_deinterlace.enhanced_deinterlace_api import EnhancedDeinterlaceApi
from bitmovin_api_sdk.encoding.filters.enhanced_deinterlace.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.filters.enhanced_deinterlace.enhanced_deinterlace_filter_list_query_params import EnhancedDeinterlaceFilterListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class AutoRestartConfiguration(object):
    @poscheck_model
    def __init__(self,
                 segments_written_timeout=None,
                 bytes_written_timeout=None,
                 frames_written_timeout=None,
                 hls_manifests_update_timeout=None,
                 dash_manifests_update_timeout=None,
                 schedule_expression=None,
                 restart_on_encoder_error=None):
        # type: (float, float, float, float, float, string_types, bool) -> None

        self._segments_written_timeout = None
        self._bytes_written_timeout = None
        self._frames_written_timeout = None
        self._hls_manifests_update_timeout = None
        self._dash_manifests_update_timeout = None
        self._schedule_expression = None
        self._restart_on_encoder_error = None
        self.discriminator = None

        if segments_written_timeout is not None:
            self.segments_written_timeout = segments_written_timeout
        if bytes_written_timeout is not None:
            self.bytes_written_timeout = bytes_written_timeout
        if frames_written_timeout is not None:
            self.frames_written_timeout = frames_written_timeout
        if hls_manifests_update_timeout is not None:
            self.hls_manifests_update_timeout = hls_manifests_update_timeout
        if dash_manifests_update_timeout is not None:
            self.dash_manifests_update_timeout = dash_manifests_update_timeout
        if schedule_expression is not None:
            self.schedule_expression = schedule_expression
        if restart_on_encoder_error is not None:
            self.restart_on_encoder_error = restart_on_encoder_error

    @property
    def openapi_types(self):
        types = {
            'segments_written_timeout': 'float',
            'bytes_written_timeout': 'float',
            'frames_written_timeout': 'float',
            'hls_manifests_update_timeout': 'float',
            'dash_manifests_update_timeout': 'float',
            'schedule_expression': 'string_types',
            'restart_on_encoder_error': 'bool'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'segments_written_timeout': 'segmentsWrittenTimeout',
            'bytes_written_timeout': 'bytesWrittenTimeout',
            'frames_written_timeout': 'framesWrittenTimeout',
            'hls_manifests_update_timeout': 'hlsManifestsUpdateTimeout',
            'dash_manifests_update_timeout': 'dashManifestsUpdateTimeout',
            'schedule_expression': 'scheduleExpression',
            'restart_on_encoder_error': 'restartOnEncoderError'
        }
        return attributes

    @property
    def segments_written_timeout(self):
        # type: () -> float
        """Gets the segments_written_timeout of this AutoRestartConfiguration.

        If no segments were generated for the given number of seconds, a restart is triggered. Minimum: 30.0

        :return: The segments_written_timeout of this AutoRestartConfiguration.
        :rtype: float
        """
        return self._segments_written_timeout

    @segments_written_timeout.setter
    def segments_written_timeout(self, segments_written_timeout):
        # type: (float) -> None
        """Sets the segments_written_timeout of this AutoRestartConfiguration.

        If no segments were generated for the given number of seconds, a restart is triggered. Minimum: 30.0

        :param segments_written_timeout: The segments_written_timeout of this AutoRestartConfiguration.
        :type: float
        """

        if segments_written_timeout is not None:
            if segments_written_timeout is not None and segments_written_timeout < 30:
                raise ValueError("Invalid value for `segments_written_timeout`, must be a value greater than or equal to `30`")
            if not isinstance(segments_written_timeout, (float, int)):
                raise TypeError("Invalid type for `segments_written_timeout`, type has to be `float`")

        self._segments_written_timeout = segments_written_timeout

    @property
    def bytes_written_timeout(self):
        # type: () -> float
        """Gets the bytes_written_timeout of this AutoRestartConfiguration.

        If no data was written for the given number of seconds, a restart is triggered. Minimum: 30.0

        :return: The bytes_written_timeout of this AutoRestartConfiguration.
        :rtype: float
        """
        return self._bytes_written_timeout

    @bytes_written_timeout.setter
    def bytes_written_timeout(self, bytes_written_timeout):
        # type: (float) -> None
        """Sets the bytes_written_timeout of this AutoRestartConfiguration.

        If no data was written for the given number of seconds, a restart is triggered. Minimum: 30.0

        :param bytes_written_timeout: The bytes_written_timeout of this AutoRestartConfiguration.
        :type: float
        """

        if bytes_written_timeout is not None:
            if bytes_written_timeout is not None and bytes_written_timeout < 30:
                raise ValueError("Invalid value for `bytes_written_timeout`, must be a value greater than or equal to `30`")
            if not isinstance(bytes_written_timeout, (float, int)):
                raise TypeError("Invalid type for `bytes_written_timeout`, type has to be `float`")

        self._bytes_written_timeout = bytes_written_timeout

    @property
    def frames_written_timeout(self):
        # type: () -> float
        """Gets the frames_written_timeout of this AutoRestartConfiguration.

        If no frames were generated for the given number of seconds, a restart is triggered. Minimum: 30.0

        :return: The frames_written_timeout of this AutoRestartConfiguration.
        :rtype: float
        """
        return self._frames_written_timeout

    @frames_written_timeout.setter
    def frames_written_timeout(self, frames_written_timeout):
        # type: (float) -> None
        """Sets the frames_written_timeout of this AutoRestartConfiguration.

        If no frames were generated for the given number of seconds, a restart is triggered. Minimum: 30.0

        :param frames_written_timeout: The frames_written_timeout of this AutoRestartConfiguration.
        :type: float
        """

        if frames_written_timeout is not None:
            if frames_written_timeout is not None and frames_written_timeout < 30:
                raise ValueError("Invalid value for `frames_written_timeout`, must be a value greater than or equal to `30`")
            if not isinstance(frames_written_timeout, (float, int)):
                raise TypeError("Invalid type for `frames_written_timeout`, type has to be `float`")

        self._frames_written_timeout = frames_written_timeout

    @property
    def hls_manifests_update_timeout(self):
        # type: () -> float
        """Gets the hls_manifests_update_timeout of this AutoRestartConfiguration.

        If HLS manifests were not updated for the given number of seconds, a restart is triggered. Minimum: 30.0

        :return: The hls_manifests_update_timeout of this AutoRestartConfiguration.
        :rtype: float
        """
        return self._hls_manifests_update_timeout

    @hls_manifests_update_timeout.setter
    def hls_manifests_update_timeout(self, hls_manifests_update_timeout):
        # type: (float) -> None
        """Sets the hls_manifests_update_timeout of this AutoRestartConfiguration.

        If HLS manifests were not updated for the given number of seconds, a restart is triggered. Minimum: 30.0

        :param hls_manifests_update_timeout: The hls_manifests_update_timeout of this AutoRestartConfiguration.
        :type: float
        """

        if hls_manifests_update_timeout is not None:
            if hls_manifests_update_timeout is not None and hls_manifests_update_timeout < 30:
                raise ValueError("Invalid value for `hls_manifests_update_timeout`, must be a value greater than or equal to `30`")
            if not isinstance(hls_manifests_update_timeout, (float, int)):
                raise TypeError("Invalid type for `hls_manifests_update_timeout`, type has to be `float`")

        self._hls_manifests_update_timeout = hls_manifests_update_timeout

    @property
    def dash_manifests_update_timeout(self):
        # type: () -> float
        """Gets the dash_manifests_update_timeout of this AutoRestartConfiguration.

        If DASH manifests were not updated for the given number of seconds, a restart is triggered. Minimum: 30.0

        :return: The dash_manifests_update_timeout of this AutoRestartConfiguration.
        :rtype: float
        """
        return self._dash_manifests_update_timeout

    @dash_manifests_update_timeout.setter
    def dash_manifests_update_timeout(self, dash_manifests_update_timeout):
        # type: (float) -> None
        """Sets the dash_manifests_update_timeout of this AutoRestartConfiguration.

        If DASH manifests were not updated for the given number of seconds, a restart is triggered. Minimum: 30.0

        :param dash_manifests_update_timeout: The dash_manifests_update_timeout of this AutoRestartConfiguration.
        :type: float
        """

        if dash_manifests_update_timeout is not None:
            if dash_manifests_update_timeout is not None and dash_manifests_update_timeout < 30:
                raise ValueError("Invalid value for `dash_manifests_update_timeout`, must be a value greater than or equal to `30`")
            if not isinstance(dash_manifests_update_timeout, (float, int)):
                raise TypeError("Invalid type for `dash_manifests_update_timeout`, type has to be `float`")

        self._dash_manifests_update_timeout = dash_manifests_update_timeout

    @property
    def schedule_expression(self):
        # type: () -> string_types
        """Gets the schedule_expression of this AutoRestartConfiguration.

        Defines a schedule for restarts using the unix crontab syntax. This example would trigger a restart every monday at 05:30 (AM)

        :return: The schedule_expression of this AutoRestartConfiguration.
        :rtype: string_types
        """
        return self._schedule_expression

    @schedule_expression.setter
    def schedule_expression(self, schedule_expression):
        # type: (string_types) -> None
        """Sets the schedule_expression of this AutoRestartConfiguration.

        Defines a schedule for restarts using the unix crontab syntax. This example would trigger a restart every monday at 05:30 (AM)

        :param schedule_expression: The schedule_expression of this AutoRestartConfiguration.
        :type: string_types
        """

        if schedule_expression is not None:
            if not isinstance(schedule_expression, string_types):
                raise TypeError("Invalid type for `schedule_expression`, type has to be `string_types`")

        self._schedule_expression = schedule_expression

    @property
    def restart_on_encoder_error(self):
        # type: () -> bool
        """Gets the restart_on_encoder_error of this AutoRestartConfiguration.

        Defines if the encoding should be restarted in case of an error during encoding.

        :return: The restart_on_encoder_error of this AutoRestartConfiguration.
        :rtype: bool
        """
        return self._restart_on_encoder_error

    @restart_on_encoder_error.setter
    def restart_on_encoder_error(self, restart_on_encoder_error):
        # type: (bool) -> None
        """Sets the restart_on_encoder_error of this AutoRestartConfiguration.

        Defines if the encoding should be restarted in case of an error during encoding.

        :param restart_on_encoder_error: The restart_on_encoder_error of this AutoRestartConfiguration.
        :type: bool
        """

        if restart_on_encoder_error is not None:
            if not isinstance(restart_on_encoder_error, bool):
                raise TypeError("Invalid type for `restart_on_encoder_error`, type has to be `bool`")

        self._restart_on_encoder_error = restart_on_encoder_error

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AutoRestartConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class PTSAlignMode(Enum):
    ALIGN_ZERO_NEGATIVE_CTO = "ALIGN_ZERO_NEGATIVE_CTO"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AudioVolumeUnit(Enum):
    PERCENT = "PERCENT"
    DB = "DB"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.frame_id_id3_tag import FrameIdId3Tag
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.id3.frame_id.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.id3.frame_id.frame_id_id3_tag_list_query_params import FrameIdId3TagListQueryParams


class FrameIdApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(FrameIdApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, muxing_id, frame_id_id3_tag, **kwargs):
        # type: (string_types, string_types, FrameIdId3Tag, dict) -> FrameIdId3Tag
        """Add Frame ID ID3 Tag to a Progressive TS muxing

        :param encoding_id: ID of the Encoding.
        :type encoding_id: string_types, required
        :param muxing_id: ID of the Progressive TS muxing
        :type muxing_id: string_types, required
        :param frame_id_id3_tag: The Frame ID ID3 Tag to be created
        :type frame_id_id3_tag: FrameIdId3Tag, required
        :return: FrameId ID3 Tag
        :rtype: FrameIdId3Tag
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/muxings/progressive-ts/{muxing_id}/id3/frame-id',
            frame_id_id3_tag,
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id},
            type=FrameIdId3Tag,
            **kwargs
        )

    def delete(self, encoding_id, muxing_id, id3_tag_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> BitmovinResponse
        """Delete Frame ID ID3 Tag of a Progressive TS muxing

        :param encoding_id: ID of the Encoding.
        :type encoding_id: string_types, required
        :param muxing_id: ID of the Progressive TS muxing
        :type muxing_id: string_types, required
        :param id3_tag_id: ID of the Frame ID ID3 Tag
        :type id3_tag_id: string_types, required
        :return: ID of the Frame ID ID3 Tag
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/muxings/progressive-ts/{muxing_id}/id3/frame-id/{id3_tag_id}',
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id, 'id3_tag_id': id3_tag_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, muxing_id, id3_tag_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> FrameIdId3Tag
        """Frame ID ID3 Tag Details of a Progressive TS muxing

        :param encoding_id: ID of the Encoding.
        :type encoding_id: string_types, required
        :param muxing_id: ID of the Progressive TS muxing
        :type muxing_id: string_types, required
        :param id3_tag_id: ID of the Frame ID ID3 Tag
        :type id3_tag_id: string_types, required
        :return: Frame ID ID3 Tag
        :rtype: FrameIdId3Tag
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/muxings/progressive-ts/{muxing_id}/id3/frame-id/{id3_tag_id}',
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id, 'id3_tag_id': id3_tag_id},
            type=FrameIdId3Tag,
            **kwargs
        )

    def list(self, encoding_id, muxing_id, query_params=None, **kwargs):
        # type: (string_types, string_types, FrameIdId3TagListQueryParams, dict) -> FrameIdId3Tag
        """List Frame ID ID3 Tags of a Progressive TS muxing

        :param encoding_id: ID of the Encoding.
        :type encoding_id: string_types, required
        :param muxing_id: ID of the Progressive TS muxing
        :type muxing_id: string_types, required
        :param query_params: Query parameters
        :type query_params: FrameIdId3TagListQueryParams
        :return: List of Frame ID ID3 Tags
        :rtype: FrameIdId3Tag
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/muxings/progressive-ts/{muxing_id}/id3/frame-id',
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id},
            query_params=query_params,
            pagination_response=True,
            type=FrameIdId3Tag,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.ad_analytics_attribute import AdAnalyticsAttribute
from bitmovin_api_sdk.models.analytics_interval import AnalyticsInterval
from bitmovin_api_sdk.models.analytics_query_timeframe import AnalyticsQueryTimeframe
import pprint
import six


class AdAnalyticsQueryRequest(AnalyticsQueryTimeframe):
    @poscheck_model
    def __init__(self,
                 start=None,
                 end=None,
                 license_key=None,
                 filters=None,
                 order_by=None,
                 dimension=None,
                 interval=None,
                 group_by=None,
                 limit=None,
                 offset=None):
        # type: (datetime, datetime, string_types, list[AdAnalyticsAbstractFilter], list[AdAnalyticsOrderByEntry], AdAnalyticsAttribute, AnalyticsInterval, list[AdAnalyticsAttribute], int, int) -> None
        super(AdAnalyticsQueryRequest, self).__init__(start=start, end=end)

        self._license_key = None
        self._filters = list()
        self._order_by = list()
        self._dimension = None
        self._interval = None
        self._group_by = list()
        self._limit = None
        self._offset = None
        self.discriminator = None

        if license_key is not None:
            self.license_key = license_key
        if filters is not None:
            self.filters = filters
        if order_by is not None:
            self.order_by = order_by
        if dimension is not None:
            self.dimension = dimension
        if interval is not None:
            self.interval = interval
        if group_by is not None:
            self.group_by = group_by
        if limit is not None:
            self.limit = limit
        if offset is not None:
            self.offset = offset

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(AdAnalyticsQueryRequest, self), 'openapi_types'):
            types = getattr(super(AdAnalyticsQueryRequest, self), 'openapi_types')

        types.update({
            'license_key': 'string_types',
            'filters': 'list[AdAnalyticsAbstractFilter]',
            'order_by': 'list[AdAnalyticsOrderByEntry]',
            'dimension': 'AdAnalyticsAttribute',
            'interval': 'AnalyticsInterval',
            'group_by': 'list[AdAnalyticsAttribute]',
            'limit': 'int',
            'offset': 'int'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(AdAnalyticsQueryRequest, self), 'attribute_map'):
            attributes = getattr(super(AdAnalyticsQueryRequest, self), 'attribute_map')

        attributes.update({
            'license_key': 'licenseKey',
            'filters': 'filters',
            'order_by': 'orderBy',
            'dimension': 'dimension',
            'interval': 'interval',
            'group_by': 'groupBy',
            'limit': 'limit',
            'offset': 'offset'
        })
        return attributes

    @property
    def license_key(self):
        # type: () -> string_types
        """Gets the license_key of this AdAnalyticsQueryRequest.

        Analytics license key (required)

        :return: The license_key of this AdAnalyticsQueryRequest.
        :rtype: string_types
        """
        return self._license_key

    @license_key.setter
    def license_key(self, license_key):
        # type: (string_types) -> None
        """Sets the license_key of this AdAnalyticsQueryRequest.

        Analytics license key (required)

        :param license_key: The license_key of this AdAnalyticsQueryRequest.
        :type: string_types
        """

        if license_key is not None:
            if not isinstance(license_key, string_types):
                raise TypeError("Invalid type for `license_key`, type has to be `string_types`")

        self._license_key = license_key

    @property
    def filters(self):
        # type: () -> list[AdAnalyticsAbstractFilter]
        """Gets the filters of this AdAnalyticsQueryRequest.

        Analytics Query Filters  Each filter requires 3 properties: name, operator and value.   Valid operators are [IN, EQ, NE, LT, LTE, GT, GTE, CONTAINS, NOTCONTAINS] 

        :return: The filters of this AdAnalyticsQueryRequest.
        :rtype: list[AdAnalyticsAbstractFilter]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        # type: (list) -> None
        """Sets the filters of this AdAnalyticsQueryRequest.

        Analytics Query Filters  Each filter requires 3 properties: name, operator and value.   Valid operators are [IN, EQ, NE, LT, LTE, GT, GTE, CONTAINS, NOTCONTAINS] 

        :param filters: The filters of this AdAnalyticsQueryRequest.
        :type: list[AdAnalyticsAbstractFilter]
        """

        if filters is not None:
            if not isinstance(filters, list):
                raise TypeError("Invalid type for `filters`, type has to be `list[AdAnalyticsAbstractFilter]`")

        self._filters = filters

    @property
    def order_by(self):
        # type: () -> list[AdAnalyticsOrderByEntry]
        """Gets the order_by of this AdAnalyticsQueryRequest.


        :return: The order_by of this AdAnalyticsQueryRequest.
        :rtype: list[AdAnalyticsOrderByEntry]
        """
        return self._order_by

    @order_by.setter
    def order_by(self, order_by):
        # type: (list) -> None
        """Sets the order_by of this AdAnalyticsQueryRequest.


        :param order_by: The order_by of this AdAnalyticsQueryRequest.
        :type: list[AdAnalyticsOrderByEntry]
        """

        if order_by is not None:
            if not isinstance(order_by, list):
                raise TypeError("Invalid type for `order_by`, type has to be `list[AdAnalyticsOrderByEntry]`")

        self._order_by = order_by

    @property
    def dimension(self):
        # type: () -> AdAnalyticsAttribute
        """Gets the dimension of this AdAnalyticsQueryRequest.


        :return: The dimension of this AdAnalyticsQueryRequest.
        :rtype: AdAnalyticsAttribute
        """
        return self._dimension

    @dimension.setter
    def dimension(self, dimension):
        # type: (AdAnalyticsAttribute) -> None
        """Sets the dimension of this AdAnalyticsQueryRequest.


        :param dimension: The dimension of this AdAnalyticsQueryRequest.
        :type: AdAnalyticsAttribute
        """

        if dimension is not None:
            if not isinstance(dimension, AdAnalyticsAttribute):
                raise TypeError("Invalid type for `dimension`, type has to be `AdAnalyticsAttribute`")

        self._dimension = dimension

    @property
    def interval(self):
        # type: () -> AnalyticsInterval
        """Gets the interval of this AdAnalyticsQueryRequest.


        :return: The interval of this AdAnalyticsQueryRequest.
        :rtype: AnalyticsInterval
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        # type: (AnalyticsInterval) -> None
        """Sets the interval of this AdAnalyticsQueryRequest.


        :param interval: The interval of this AdAnalyticsQueryRequest.
        :type: AnalyticsInterval
        """

        if interval is not None:
            if not isinstance(interval, AnalyticsInterval):
                raise TypeError("Invalid type for `interval`, type has to be `AnalyticsInterval`")

        self._interval = interval

    @property
    def group_by(self):
        # type: () -> list[AdAnalyticsAttribute]
        """Gets the group_by of this AdAnalyticsQueryRequest.


        :return: The group_by of this AdAnalyticsQueryRequest.
        :rtype: list[AdAnalyticsAttribute]
        """
        return self._group_by

    @group_by.setter
    def group_by(self, group_by):
        # type: (list) -> None
        """Sets the group_by of this AdAnalyticsQueryRequest.


        :param group_by: The group_by of this AdAnalyticsQueryRequest.
        :type: list[AdAnalyticsAttribute]
        """

        if group_by is not None:
            if not isinstance(group_by, list):
                raise TypeError("Invalid type for `group_by`, type has to be `list[AdAnalyticsAttribute]`")

        self._group_by = group_by

    @property
    def limit(self):
        # type: () -> int
        """Gets the limit of this AdAnalyticsQueryRequest.

        Maximum number of rows returned (max. 200)

        :return: The limit of this AdAnalyticsQueryRequest.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        # type: (int) -> None
        """Sets the limit of this AdAnalyticsQueryRequest.

        Maximum number of rows returned (max. 200)

        :param limit: The limit of this AdAnalyticsQueryRequest.
        :type: int
        """

        if limit is not None:
            if not isinstance(limit, int):
                raise TypeError("Invalid type for `limit`, type has to be `int`")

        self._limit = limit

    @property
    def offset(self):
        # type: () -> int
        """Gets the offset of this AdAnalyticsQueryRequest.

        Offset of data

        :return: The offset of this AdAnalyticsQueryRequest.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        # type: (int) -> None
        """Sets the offset of this AdAnalyticsQueryRequest.

        Offset of data

        :param offset: The offset of this AdAnalyticsQueryRequest.
        :type: int
        """

        if offset is not None:
            if not isinstance(offset, int):
                raise TypeError("Invalid type for `offset`, type has to be `int`")

        self._offset = offset

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(AdAnalyticsQueryRequest, self), "to_dict"):
            result = super(AdAnalyticsQueryRequest, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdAnalyticsQueryRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class VideoFormat(Enum):
    UNDEFINED = "UNDEFINED"
    COMPONENT = "COMPONENT"
    PAL = "PAL"
    NTSC = "NTSC"
    SECAM = "SECAM"
    MAC = "MAC"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.live_media_ingest_output import LiveMediaIngestOutput
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.outputs.live_media_ingest.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.outputs.live_media_ingest.live_media_ingest_output_list_query_params import LiveMediaIngestOutputListQueryParams


class LiveMediaIngestApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(LiveMediaIngestApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, live_media_ingest_output, **kwargs):
        # type: (LiveMediaIngestOutput, dict) -> LiveMediaIngestOutput
        """Create Live Media Ingest Output

        :param live_media_ingest_output: The Live Media Ingest output to be created
        :type live_media_ingest_output: LiveMediaIngestOutput, required
        :return: Live Media Ingest output
        :rtype: LiveMediaIngestOutput
        """

        return self.api_client.post(
            '/encoding/outputs/live-media-ingest',
            live_media_ingest_output,
            type=LiveMediaIngestOutput,
            **kwargs
        )

    def delete(self, output_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete Live Media Ingest Output

        :param output_id: Id of the output
        :type output_id: string_types, required
        :return: Id of the output
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/outputs/live-media-ingest/{output_id}',
            path_params={'output_id': output_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, output_id, **kwargs):
        # type: (string_types, dict) -> LiveMediaIngestOutput
        """Live Media Ingest Output Details

        :param output_id: Id of the output
        :type output_id: string_types, required
        :return: Live Media Ingest output
        :rtype: LiveMediaIngestOutput
        """

        return self.api_client.get(
            '/encoding/outputs/live-media-ingest/{output_id}',
            path_params={'output_id': output_id},
            type=LiveMediaIngestOutput,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (LiveMediaIngestOutputListQueryParams, dict) -> LiveMediaIngestOutput
        """List Live Media Ingest Outputs

        :param query_params: Query parameters
        :type query_params: LiveMediaIngestOutputListQueryParams
        :return: List of Live Media Ingest outputs
        :rtype: LiveMediaIngestOutput
        """

        return self.api_client.get(
            '/encoding/outputs/live-media-ingest',
            query_params=query_params,
            pagination_response=True,
            type=LiveMediaIngestOutput,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
from bitmovin_api_sdk.models.policy import Policy
import pprint
import six


class Acl(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 resource=None,
                 policy=None,
                 permissions=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, string_types, Policy, list[Permission]) -> None
        super(Acl, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._resource = None
        self._policy = None
        self._permissions = list()
        self.discriminator = None

        if resource is not None:
            self.resource = resource
        if policy is not None:
            self.policy = policy
        if permissions is not None:
            self.permissions = permissions

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(Acl, self), 'openapi_types'):
            types = getattr(super(Acl, self), 'openapi_types')

        types.update({
            'resource': 'string_types',
            'policy': 'Policy',
            'permissions': 'list[Permission]'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(Acl, self), 'attribute_map'):
            attributes = getattr(super(Acl, self), 'attribute_map')

        attributes.update({
            'resource': 'resource',
            'policy': 'policy',
            'permissions': 'permissions'
        })
        return attributes

    @property
    def resource(self):
        # type: () -> string_types
        """Gets the resource of this Acl.

        Resource to define the permission for. (required)

        :return: The resource of this Acl.
        :rtype: string_types
        """
        return self._resource

    @resource.setter
    def resource(self, resource):
        # type: (string_types) -> None
        """Sets the resource of this Acl.

        Resource to define the permission for. (required)

        :param resource: The resource of this Acl.
        :type: string_types
        """

        if resource is not None:
            if not isinstance(resource, string_types):
                raise TypeError("Invalid type for `resource`, type has to be `string_types`")

        self._resource = resource

    @property
    def policy(self):
        # type: () -> Policy
        """Gets the policy of this Acl.


        :return: The policy of this Acl.
        :rtype: Policy
        """
        return self._policy

    @policy.setter
    def policy(self, policy):
        # type: (Policy) -> None
        """Sets the policy of this Acl.


        :param policy: The policy of this Acl.
        :type: Policy
        """

        if policy is not None:
            if not isinstance(policy, Policy):
                raise TypeError("Invalid type for `policy`, type has to be `Policy`")

        self._policy = policy

    @property
    def permissions(self):
        # type: () -> list[Permission]
        """Gets the permissions of this Acl.

        Permissions to assign. (required)

        :return: The permissions of this Acl.
        :rtype: list[Permission]
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        # type: (list) -> None
        """Sets the permissions of this Acl.

        Permissions to assign. (required)

        :param permissions: The permissions of this Acl.
        :type: list[Permission]
        """

        if permissions is not None:
            if not isinstance(permissions, list):
                raise TypeError("Invalid type for `permissions`, type has to be `list[Permission]`")

        self._permissions = permissions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(Acl, self), "to_dict"):
            result = super(Acl, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Acl):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.encodings.muxings.ts.ts_api import TsApi
from bitmovin_api_sdk.encoding.encodings.muxings.ts.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.ts.drm.drm_api import DrmApi
from bitmovin_api_sdk.encoding.encodings.muxings.ts.ts_muxing_list_query_params import TsMuxingListQueryParams



from bitmovin_api_sdk.encoding.inputs.ftp.ftp_api import FtpApi
from bitmovin_api_sdk.encoding.inputs.ftp.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.inputs.ftp.ftp_input_list_query_params import FtpInputListQueryParams



from bitmovin_api_sdk.notifications.webhooks.encoding.encoding_api import EncodingApi
from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.encodings_api import EncodingsApi
from bitmovin_api_sdk.notifications.webhooks.encoding.manifest.manifest_api import ManifestApi



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.azure_account_region_settings import AzureAccountRegionSettings
from bitmovin_api_sdk.models.azure_cloud_region import AzureCloudRegion
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.infrastructure.azure.regions.azure_account_region_settings_list_query_params import AzureAccountRegionSettingsListQueryParams


class RegionsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(RegionsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, infrastructure_id, region, azure_account_region_settings, **kwargs):
        # type: (string_types, AzureCloudRegion, AzureAccountRegionSettings, dict) -> AzureAccountRegionSettings
        """Add Azure Region Setting

        :param infrastructure_id: Id of the Azure account
        :type infrastructure_id: string_types, required
        :param region: Azure region.
        :type region: AzureCloudRegion, required
        :param azure_account_region_settings: The Azure Region Settings to be added
        :type azure_account_region_settings: AzureAccountRegionSettings, required
        :return: Azure account
        :rtype: AzureAccountRegionSettings
        """

        return self.api_client.post(
            '/encoding/infrastructure/azure/{infrastructure_id}/regions/{region}',
            azure_account_region_settings,
            path_params={'infrastructure_id': infrastructure_id, 'region': region},
            type=AzureAccountRegionSettings,
            **kwargs
        )

    def delete(self, infrastructure_id, region, **kwargs):
        # type: (string_types, AzureCloudRegion, dict) -> AzureAccountRegionSettings
        """Delete Azure Region Settings

        :param infrastructure_id: Id of the Azure account
        :type infrastructure_id: string_types, required
        :param region: Azure region.
        :type region: AzureCloudRegion, required
        :return: Region settings for specified region
        :rtype: AzureAccountRegionSettings
        """

        return self.api_client.delete(
            '/encoding/infrastructure/azure/{infrastructure_id}/regions/{region}',
            path_params={'infrastructure_id': infrastructure_id, 'region': region},
            type=AzureAccountRegionSettings,
            **kwargs
        )

    def get(self, infrastructure_id, region, **kwargs):
        # type: (string_types, AzureCloudRegion, dict) -> AzureAccountRegionSettings
        """Azure Region Settings Details

        :param infrastructure_id: Id of the Azure account
        :type infrastructure_id: string_types, required
        :param region: Azure region.
        :type region: AzureCloudRegion, required
        :return: Region settings for specified region
        :rtype: AzureAccountRegionSettings
        """

        return self.api_client.get(
            '/encoding/infrastructure/azure/{infrastructure_id}/regions/{region}',
            path_params={'infrastructure_id': infrastructure_id, 'region': region},
            type=AzureAccountRegionSettings,
            **kwargs
        )

    def list(self, infrastructure_id, query_params=None, **kwargs):
        # type: (string_types, AzureAccountRegionSettingsListQueryParams, dict) -> AzureAccountRegionSettings
        """List Azure Region Settings

        :param infrastructure_id: Id of the Azure account
        :type infrastructure_id: string_types, required
        :param query_params: Query parameters
        :type query_params: AzureAccountRegionSettingsListQueryParams
        :return: List of Azure Region Settings
        :rtype: AzureAccountRegionSettings
        """

        return self.api_client.get(
            '/encoding/infrastructure/azure/{infrastructure_id}/regions',
            path_params={'infrastructure_id': infrastructure_id},
            query_params=query_params,
            pagination_response=True,
            type=AzureAccountRegionSettings,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class DecodingErrorMode(Enum):
    FAIL_ON_ERROR = "FAIL_ON_ERROR"
    DUPLICATE_FRAMES = "DUPLICATE_FRAMES"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.muxing import Muxing
from bitmovin_api_sdk.models.progressive_webm_muxing_manifest_type import ProgressiveWebmMuxingManifestType
from bitmovin_api_sdk.models.stream_conditions_mode import StreamConditionsMode
import pprint
import six


class ProgressiveWebmMuxing(Muxing):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 streams=None,
                 outputs=None,
                 avg_bitrate=None,
                 min_bitrate=None,
                 max_bitrate=None,
                 ignored_by=None,
                 stream_conditions_mode=None,
                 filename=None,
                 manifest_type=None,
                 segment_length=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, list[MuxingStream], list[EncodingOutput], int, int, int, list[Ignoring], StreamConditionsMode, string_types, ProgressiveWebmMuxingManifestType, float) -> None
        super(ProgressiveWebmMuxing, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, streams=streams, outputs=outputs, avg_bitrate=avg_bitrate, min_bitrate=min_bitrate, max_bitrate=max_bitrate, ignored_by=ignored_by, stream_conditions_mode=stream_conditions_mode)

        self._filename = None
        self._manifest_type = None
        self._segment_length = None
        self.discriminator = None

        if filename is not None:
            self.filename = filename
        if manifest_type is not None:
            self.manifest_type = manifest_type
        if segment_length is not None:
            self.segment_length = segment_length

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(ProgressiveWebmMuxing, self), 'openapi_types'):
            types = getattr(super(ProgressiveWebmMuxing, self), 'openapi_types')

        types.update({
            'filename': 'string_types',
            'manifest_type': 'ProgressiveWebmMuxingManifestType',
            'segment_length': 'float'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(ProgressiveWebmMuxing, self), 'attribute_map'):
            attributes = getattr(super(ProgressiveWebmMuxing, self), 'attribute_map')

        attributes.update({
            'filename': 'filename',
            'manifest_type': 'manifestType',
            'segment_length': 'segmentLength'
        })
        return attributes

    @property
    def filename(self):
        # type: () -> string_types
        """Gets the filename of this ProgressiveWebmMuxing.

        Name of the new Video

        :return: The filename of this ProgressiveWebmMuxing.
        :rtype: string_types
        """
        return self._filename

    @filename.setter
    def filename(self, filename):
        # type: (string_types) -> None
        """Sets the filename of this ProgressiveWebmMuxing.

        Name of the new Video

        :param filename: The filename of this ProgressiveWebmMuxing.
        :type: string_types
        """

        if filename is not None:
            if not isinstance(filename, string_types):
                raise TypeError("Invalid type for `filename`, type has to be `string_types`")

        self._filename = filename

    @property
    def manifest_type(self):
        # type: () -> ProgressiveWebmMuxingManifestType
        """Gets the manifest_type of this ProgressiveWebmMuxing.


        :return: The manifest_type of this ProgressiveWebmMuxing.
        :rtype: ProgressiveWebmMuxingManifestType
        """
        return self._manifest_type

    @manifest_type.setter
    def manifest_type(self, manifest_type):
        # type: (ProgressiveWebmMuxingManifestType) -> None
        """Sets the manifest_type of this ProgressiveWebmMuxing.


        :param manifest_type: The manifest_type of this ProgressiveWebmMuxing.
        :type: ProgressiveWebmMuxingManifestType
        """

        if manifest_type is not None:
            if not isinstance(manifest_type, ProgressiveWebmMuxingManifestType):
                raise TypeError("Invalid type for `manifest_type`, type has to be `ProgressiveWebmMuxingManifestType`")

        self._manifest_type = manifest_type

    @property
    def segment_length(self):
        # type: () -> float
        """Gets the segment_length of this ProgressiveWebmMuxing.

        Determines the length of segments in seconds if manifestType is set to DASH_ON_DEMAND. Defaults to 4 seconds

        :return: The segment_length of this ProgressiveWebmMuxing.
        :rtype: float
        """
        return self._segment_length

    @segment_length.setter
    def segment_length(self, segment_length):
        # type: (float) -> None
        """Sets the segment_length of this ProgressiveWebmMuxing.

        Determines the length of segments in seconds if manifestType is set to DASH_ON_DEMAND. Defaults to 4 seconds

        :param segment_length: The segment_length of this ProgressiveWebmMuxing.
        :type: float
        """

        if segment_length is not None:
            if not isinstance(segment_length, (float, int)):
                raise TypeError("Invalid type for `segment_length`, type has to be `float`")

        self._segment_length = segment_length

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(ProgressiveWebmMuxing, self), "to_dict"):
            result = super(ProgressiveWebmMuxing, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProgressiveWebmMuxing):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class DolbyVisionProfile(Enum):
    DVHE_04 = "DVHE_04"
    DVHE_05 = "DVHE_05"
    DVHE_07 = "DVHE_07"
    HEV1_08 = "HEV1_08"
    AVC3_09 = "AVC3_09"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class AnalyticsAvgConcurrentViewersResponse(object):
    @poscheck_model
    def __init__(self,
                 rows=None,
                 row_count=None,
                 column_labels=None):
        # type: (list[float], int, list[AnalyticsColumnLabel]) -> None

        self._rows = list()
        self._row_count = None
        self._column_labels = list()
        self.discriminator = None

        if rows is not None:
            self.rows = rows
        if row_count is not None:
            self.row_count = row_count
        if column_labels is not None:
            self.column_labels = column_labels

    @property
    def openapi_types(self):
        types = {
            'rows': 'list[float]',
            'row_count': 'int',
            'column_labels': 'list[AnalyticsColumnLabel]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'rows': 'rows',
            'row_count': 'rowCount',
            'column_labels': 'columnLabels'
        }
        return attributes

    @property
    def rows(self):
        # type: () -> list[float]
        """Gets the rows of this AnalyticsAvgConcurrentViewersResponse.


        :return: The rows of this AnalyticsAvgConcurrentViewersResponse.
        :rtype: list[float]
        """
        return self._rows

    @rows.setter
    def rows(self, rows):
        # type: (list) -> None
        """Sets the rows of this AnalyticsAvgConcurrentViewersResponse.


        :param rows: The rows of this AnalyticsAvgConcurrentViewersResponse.
        :type: list[float]
        """

        if rows is not None:
            if not isinstance(rows, list):
                raise TypeError("Invalid type for `rows`, type has to be `list[float]`")

        self._rows = rows

    @property
    def row_count(self):
        # type: () -> int
        """Gets the row_count of this AnalyticsAvgConcurrentViewersResponse.

        Number of rows returned

        :return: The row_count of this AnalyticsAvgConcurrentViewersResponse.
        :rtype: int
        """
        return self._row_count

    @row_count.setter
    def row_count(self, row_count):
        # type: (int) -> None
        """Sets the row_count of this AnalyticsAvgConcurrentViewersResponse.

        Number of rows returned

        :param row_count: The row_count of this AnalyticsAvgConcurrentViewersResponse.
        :type: int
        """

        if row_count is not None:
            if not isinstance(row_count, int):
                raise TypeError("Invalid type for `row_count`, type has to be `int`")

        self._row_count = row_count

    @property
    def column_labels(self):
        # type: () -> list[AnalyticsColumnLabel]
        """Gets the column_labels of this AnalyticsAvgConcurrentViewersResponse.


        :return: The column_labels of this AnalyticsAvgConcurrentViewersResponse.
        :rtype: list[AnalyticsColumnLabel]
        """
        return self._column_labels

    @column_labels.setter
    def column_labels(self, column_labels):
        # type: (list) -> None
        """Sets the column_labels of this AnalyticsAvgConcurrentViewersResponse.


        :param column_labels: The column_labels of this AnalyticsAvgConcurrentViewersResponse.
        :type: list[AnalyticsColumnLabel]
        """

        if column_labels is not None:
            if not isinstance(column_labels, list):
                raise TypeError("Invalid type for `column_labels`, type has to be `list[AnalyticsColumnLabel]`")

        self._column_labels = column_labels

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsAvgConcurrentViewersResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.simple_encoding_live_cloud_region import SimpleEncodingLiveCloudRegion
from bitmovin_api_sdk.models.simple_encoding_live_job_input import SimpleEncodingLiveJobInput
from bitmovin_api_sdk.models.simple_encoding_live_job_status import SimpleEncodingLiveJobStatus
import pprint
import six


class SimpleEncodingLiveJobResponse(object):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 status=None,
                 encoding_id=None,
                 encoder_ip=None,
                 stream_key=None,
                 input_=None,
                 outputs=None,
                 errors=None,
                 created_at=None,
                 modified_at=None,
                 name=None,
                 cloud_region=None):
        # type: (string_types, SimpleEncodingLiveJobStatus, string_types, string_types, string_types, SimpleEncodingLiveJobInput, list[SimpleEncodingLiveJobOutput], list[SimpleEncodingVodJobErrors], datetime, datetime, string_types, SimpleEncodingLiveCloudRegion) -> None

        self._id = None
        self._status = None
        self._encoding_id = None
        self._encoder_ip = None
        self._stream_key = None
        self._input = None
        self._outputs = list()
        self._errors = list()
        self._created_at = None
        self._modified_at = None
        self._name = None
        self._cloud_region = None
        self.discriminator = None

        if id_ is not None:
            self.id = id_
        if status is not None:
            self.status = status
        if encoding_id is not None:
            self.encoding_id = encoding_id
        if encoder_ip is not None:
            self.encoder_ip = encoder_ip
        if stream_key is not None:
            self.stream_key = stream_key
        if input_ is not None:
            self.input = input_
        if outputs is not None:
            self.outputs = outputs
        if errors is not None:
            self.errors = errors
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if name is not None:
            self.name = name
        if cloud_region is not None:
            self.cloud_region = cloud_region

    @property
    def openapi_types(self):
        types = {
            'id': 'string_types',
            'status': 'SimpleEncodingLiveJobStatus',
            'encoding_id': 'string_types',
            'encoder_ip': 'string_types',
            'stream_key': 'string_types',
            'input': 'SimpleEncodingLiveJobInput',
            'outputs': 'list[SimpleEncodingLiveJobOutput]',
            'errors': 'list[SimpleEncodingVodJobErrors]',
            'created_at': 'datetime',
            'modified_at': 'datetime',
            'name': 'string_types',
            'cloud_region': 'SimpleEncodingLiveCloudRegion'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'id': 'id',
            'status': 'status',
            'encoding_id': 'encodingId',
            'encoder_ip': 'encoderIp',
            'stream_key': 'streamKey',
            'input': 'input',
            'outputs': 'outputs',
            'errors': 'errors',
            'created_at': 'createdAt',
            'modified_at': 'modifiedAt',
            'name': 'name',
            'cloud_region': 'cloudRegion'
        }
        return attributes

    @property
    def id(self):
        # type: () -> string_types
        """Gets the id of this SimpleEncodingLiveJobResponse.

        The identifier of the Simple Encoding Live Job

        :return: The id of this SimpleEncodingLiveJobResponse.
        :rtype: string_types
        """
        return self._id

    @id.setter
    def id(self, id_):
        # type: (string_types) -> None
        """Sets the id of this SimpleEncodingLiveJobResponse.

        The identifier of the Simple Encoding Live Job

        :param id_: The id of this SimpleEncodingLiveJobResponse.
        :type: string_types
        """

        if id_ is not None:
            if not isinstance(id_, string_types):
                raise TypeError("Invalid type for `id`, type has to be `string_types`")

        self._id = id_

    @property
    def status(self):
        # type: () -> SimpleEncodingLiveJobStatus
        """Gets the status of this SimpleEncodingLiveJobResponse.

        The current status of the Simple Encoding Live Job

        :return: The status of this SimpleEncodingLiveJobResponse.
        :rtype: SimpleEncodingLiveJobStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        # type: (SimpleEncodingLiveJobStatus) -> None
        """Sets the status of this SimpleEncodingLiveJobResponse.

        The current status of the Simple Encoding Live Job

        :param status: The status of this SimpleEncodingLiveJobResponse.
        :type: SimpleEncodingLiveJobStatus
        """

        if status is not None:
            if not isinstance(status, SimpleEncodingLiveJobStatus):
                raise TypeError("Invalid type for `status`, type has to be `SimpleEncodingLiveJobStatus`")

        self._status = status

    @property
    def encoding_id(self):
        # type: () -> string_types
        """Gets the encoding_id of this SimpleEncodingLiveJobResponse.

        The identifier of the encoding that has been created based on the job request. This is only returned once the job execution has been successful and the encoding could be started. 

        :return: The encoding_id of this SimpleEncodingLiveJobResponse.
        :rtype: string_types
        """
        return self._encoding_id

    @encoding_id.setter
    def encoding_id(self, encoding_id):
        # type: (string_types) -> None
        """Sets the encoding_id of this SimpleEncodingLiveJobResponse.

        The identifier of the encoding that has been created based on the job request. This is only returned once the job execution has been successful and the encoding could be started. 

        :param encoding_id: The encoding_id of this SimpleEncodingLiveJobResponse.
        :type: string_types
        """

        if encoding_id is not None:
            if not isinstance(encoding_id, string_types):
                raise TypeError("Invalid type for `encoding_id`, type has to be `string_types`")

        self._encoding_id = encoding_id

    @property
    def encoder_ip(self):
        # type: () -> string_types
        """Gets the encoder_ip of this SimpleEncodingLiveJobResponse.

        The IP address of the encoder for this job request. This is only returned once the job execution has been successful and the encoding could be started. Ingest is expected to be sent to this IP address. 

        :return: The encoder_ip of this SimpleEncodingLiveJobResponse.
        :rtype: string_types
        """
        return self._encoder_ip

    @encoder_ip.setter
    def encoder_ip(self, encoder_ip):
        # type: (string_types) -> None
        """Sets the encoder_ip of this SimpleEncodingLiveJobResponse.

        The IP address of the encoder for this job request. This is only returned once the job execution has been successful and the encoding could be started. Ingest is expected to be sent to this IP address. 

        :param encoder_ip: The encoder_ip of this SimpleEncodingLiveJobResponse.
        :type: string_types
        """

        if encoder_ip is not None:
            if not isinstance(encoder_ip, string_types):
                raise TypeError("Invalid type for `encoder_ip`, type has to be `string_types`")

        self._encoder_ip = encoder_ip

    @property
    def stream_key(self):
        # type: () -> string_types
        """Gets the stream_key of this SimpleEncodingLiveJobResponse.

        Stream key of the live encoder

        :return: The stream_key of this SimpleEncodingLiveJobResponse.
        :rtype: string_types
        """
        return self._stream_key

    @stream_key.setter
    def stream_key(self, stream_key):
        # type: (string_types) -> None
        """Sets the stream_key of this SimpleEncodingLiveJobResponse.

        Stream key of the live encoder

        :param stream_key: The stream_key of this SimpleEncodingLiveJobResponse.
        :type: string_types
        """

        if stream_key is not None:
            if not isinstance(stream_key, string_types):
                raise TypeError("Invalid type for `stream_key`, type has to be `string_types`")

        self._stream_key = stream_key

    @property
    def input(self):
        # type: () -> SimpleEncodingLiveJobInput
        """Gets the input of this SimpleEncodingLiveJobResponse.


        :return: The input of this SimpleEncodingLiveJobResponse.
        :rtype: SimpleEncodingLiveJobInput
        """
        return self._input

    @input.setter
    def input(self, input_):
        # type: (SimpleEncodingLiveJobInput) -> None
        """Sets the input of this SimpleEncodingLiveJobResponse.


        :param input_: The input of this SimpleEncodingLiveJobResponse.
        :type: SimpleEncodingLiveJobInput
        """

        if input_ is not None:
            if not isinstance(input_, SimpleEncodingLiveJobInput):
                raise TypeError("Invalid type for `input`, type has to be `SimpleEncodingLiveJobInput`")

        self._input = input_

    @property
    def outputs(self):
        # type: () -> list[SimpleEncodingLiveJobOutput]
        """Gets the outputs of this SimpleEncodingLiveJobResponse.


        :return: The outputs of this SimpleEncodingLiveJobResponse.
        :rtype: list[SimpleEncodingLiveJobOutput]
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        # type: (list) -> None
        """Sets the outputs of this SimpleEncodingLiveJobResponse.


        :param outputs: The outputs of this SimpleEncodingLiveJobResponse.
        :type: list[SimpleEncodingLiveJobOutput]
        """

        if outputs is not None:
            if not isinstance(outputs, list):
                raise TypeError("Invalid type for `outputs`, type has to be `list[SimpleEncodingLiveJobOutput]`")

        self._outputs = outputs

    @property
    def errors(self):
        # type: () -> list[SimpleEncodingVodJobErrors]
        """Gets the errors of this SimpleEncodingLiveJobResponse.

        Describes all the errors in cases the status of the job is 'error'. 

        :return: The errors of this SimpleEncodingLiveJobResponse.
        :rtype: list[SimpleEncodingVodJobErrors]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        # type: (list) -> None
        """Sets the errors of this SimpleEncodingLiveJobResponse.

        Describes all the errors in cases the status of the job is 'error'. 

        :param errors: The errors of this SimpleEncodingLiveJobResponse.
        :type: list[SimpleEncodingVodJobErrors]
        """

        if errors is not None:
            if not isinstance(errors, list):
                raise TypeError("Invalid type for `errors`, type has to be `list[SimpleEncodingVodJobErrors]`")

        self._errors = errors

    @property
    def created_at(self):
        # type: () -> datetime
        """Gets the created_at of this SimpleEncodingLiveJobResponse.

        Creation timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :return: The created_at of this SimpleEncodingLiveJobResponse.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        # type: (datetime) -> None
        """Sets the created_at of this SimpleEncodingLiveJobResponse.

        Creation timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :param created_at: The created_at of this SimpleEncodingLiveJobResponse.
        :type: datetime
        """

        if created_at is not None:
            if not isinstance(created_at, datetime):
                raise TypeError("Invalid type for `created_at`, type has to be `datetime`")

        self._created_at = created_at

    @property
    def modified_at(self):
        # type: () -> datetime
        """Gets the modified_at of this SimpleEncodingLiveJobResponse.

        Modified timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ. The job is updated for example when the status changes

        :return: The modified_at of this SimpleEncodingLiveJobResponse.
        :rtype: datetime
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        # type: (datetime) -> None
        """Sets the modified_at of this SimpleEncodingLiveJobResponse.

        Modified timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ. The job is updated for example when the status changes

        :param modified_at: The modified_at of this SimpleEncodingLiveJobResponse.
        :type: datetime
        """

        if modified_at is not None:
            if not isinstance(modified_at, datetime):
                raise TypeError("Invalid type for `modified_at`, type has to be `datetime`")

        self._modified_at = modified_at

    @property
    def name(self):
        # type: () -> string_types
        """Gets the name of this SimpleEncodingLiveJobResponse.

        This property will be used for naming the encoding and the manifests.

        :return: The name of this SimpleEncodingLiveJobResponse.
        :rtype: string_types
        """
        return self._name

    @name.setter
    def name(self, name):
        # type: (string_types) -> None
        """Sets the name of this SimpleEncodingLiveJobResponse.

        This property will be used for naming the encoding and the manifests.

        :param name: The name of this SimpleEncodingLiveJobResponse.
        :type: string_types
        """

        if name is not None:
            if not isinstance(name, string_types):
                raise TypeError("Invalid type for `name`, type has to be `string_types`")

        self._name = name

    @property
    def cloud_region(self):
        # type: () -> SimpleEncodingLiveCloudRegion
        """Gets the cloud_region of this SimpleEncodingLiveJobResponse.

        The cloud region that will be used for the live encoding

        :return: The cloud_region of this SimpleEncodingLiveJobResponse.
        :rtype: SimpleEncodingLiveCloudRegion
        """
        return self._cloud_region

    @cloud_region.setter
    def cloud_region(self, cloud_region):
        # type: (SimpleEncodingLiveCloudRegion) -> None
        """Sets the cloud_region of this SimpleEncodingLiveJobResponse.

        The cloud region that will be used for the live encoding

        :param cloud_region: The cloud_region of this SimpleEncodingLiveJobResponse.
        :type: SimpleEncodingLiveCloudRegion
        """

        if cloud_region is not None:
            if not isinstance(cloud_region, SimpleEncodingLiveCloudRegion):
                raise TypeError("Invalid type for `cloud_region`, type has to be `SimpleEncodingLiveCloudRegion`")

        self._cloud_region = cloud_region

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SimpleEncodingLiveJobResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.encodings.input_streams.sidecar.dolby_vision_metadata_ingest.dolby_vision_metadata_ingest_api import DolbyVisionMetadataIngestApi
from bitmovin_api_sdk.encoding.encodings.input_streams.sidecar.dolby_vision_metadata_ingest.dolby_vision_metadata_ingest_input_stream_list_query_params import DolbyVisionMetadataIngestInputStreamListQueryParams



from bitmovin_api_sdk.encoding.inputs.local.local_api import LocalApi
from bitmovin_api_sdk.encoding.inputs.local.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.inputs.local.local_input_list_query_params import LocalInputListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.codec_configuration import CodecConfiguration
import pprint
import six


class AudioConfiguration(CodecConfiguration):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 bitrate=None,
                 rate=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, int, float) -> None
        super(AudioConfiguration, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._bitrate = None
        self._rate = None
        self.discriminator = None

        if bitrate is not None:
            self.bitrate = bitrate
        if rate is not None:
            self.rate = rate

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(AudioConfiguration, self), 'openapi_types'):
            types = getattr(super(AudioConfiguration, self), 'openapi_types')

        types.update({
            'bitrate': 'int',
            'rate': 'float'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(AudioConfiguration, self), 'attribute_map'):
            attributes = getattr(super(AudioConfiguration, self), 'attribute_map')

        attributes.update({
            'bitrate': 'bitrate',
            'rate': 'rate'
        })
        return attributes

    @property
    def bitrate(self):
        # type: () -> int
        """Gets the bitrate of this AudioConfiguration.

        Target bitrate for the encoded audio in bps (required)

        :return: The bitrate of this AudioConfiguration.
        :rtype: int
        """
        return self._bitrate

    @bitrate.setter
    def bitrate(self, bitrate):
        # type: (int) -> None
        """Sets the bitrate of this AudioConfiguration.

        Target bitrate for the encoded audio in bps (required)

        :param bitrate: The bitrate of this AudioConfiguration.
        :type: int
        """

        if bitrate is not None:
            if not isinstance(bitrate, int):
                raise TypeError("Invalid type for `bitrate`, type has to be `int`")

        self._bitrate = bitrate

    @property
    def rate(self):
        # type: () -> float
        """Gets the rate of this AudioConfiguration.

        Audio sampling rate in Hz

        :return: The rate of this AudioConfiguration.
        :rtype: float
        """
        return self._rate

    @rate.setter
    def rate(self, rate):
        # type: (float) -> None
        """Sets the rate of this AudioConfiguration.

        Audio sampling rate in Hz

        :param rate: The rate of this AudioConfiguration.
        :type: float
        """

        if rate is not None:
            if not isinstance(rate, (float, int)):
                raise TypeError("Invalid type for `rate`, type has to be `float`")

        self._rate = rate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(AudioConfiguration, self), "to_dict"):
            result = super(AudioConfiguration, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AudioConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
